@@ -18,8 +18,8 @@ class DataCheck(ABC):
         Inspects and validates the input data, runs any necessary calculations or algorithms, and returns a list of warnings and errors if applicable.
 
         Arguments:
-            X (ww.DataTable, pd.DataFrame): The input data of shape [n_samples, n_features]
-            y (ww.DataColumn, pd.Series, optional): The target data of length [n_samples]
+            X (pd.DataFrame): The input data of shape [n_samples, n_features]
+            y (pd.Series, optional): The target data of length [n_samples]
 
         Returns:
             dict (DataCheckMessage): Dictionary of DataCheckError and DataCheckWarning messages
