@@ -1,5 +1,3 @@
-import pandas as pd
-
 from evalml.data_checks import (
     DataCheck,
     DataCheckAction,
@@ -54,9 +52,8 @@ class TargetLeakageDataCheck(DataCheck):
     def _calculate_mutual_information(self, X, y):
         highly_corr_cols = []
         for col in X.columns:
-            cols_to_compare = infer_feature_types(
-                pd.DataFrame({col: X[col], str(col) + "y": y})
-            )
+            cols_to_compare = X.ww[[col]]
+            cols_to_compare.ww[str(col) + "y"] = y
             mutual_info = cols_to_compare.ww.mutual_information()
             if (
                 len(mutual_info) > 0
@@ -87,14 +84,15 @@ class TargetLeakageDataCheck(DataCheck):
             ... })
             >>> y = pd.Series([10, 42, 31, 51, 40])
             >>> target_leakage_check = TargetLeakageDataCheck(pct_corr_threshold=0.95)
-            >>> assert target_leakage_check.validate(X, y) == {"warnings": [{"message": "Column 'leak' is 95.0% or more correlated with the target",\
-                                                                             "data_check_name": "TargetLeakageDataCheck",\
-                                                                             "level": "warning",\
-                                                                             "code": "TARGET_LEAKAGE",\
-                                                                             "details": {"column": "leak"}}],\
-                                                               "errors": [],\
-                                                               "actions": [{"code": "DROP_COL",\
-                                                                            "metadata": {"column": "leak"}}]}
+            >>> assert target_leakage_check.validate(X, y) == {
+            ...     "warnings": [{"message": "Column 'leak' is 95.0% or more correlated with the target",
+            ...                   "data_check_name": "TargetLeakageDataCheck",
+            ...                   "level": "warning",
+            ...                   "code": "TARGET_LEAKAGE",
+            ...                   "details": {"column": "leak"}}],
+            ...     "errors": [],
+            ...     "actions": [{"code": "DROP_COL",
+            ...                  "metadata": {"column": "leak"}}]}
         """
         results = {"warnings": [], "errors": [], "actions": []}
 
