@@ -17,13 +17,10 @@ from .graphs import (
     partial_dependence,
     precision_recall_curve,
     roc_curve,
-    t_sne
-)
-from .prediction_explanations import (
-    explain_predictions,
-    explain_predictions_best_worst
+    t_sne,
 )
+from .prediction_explanations import explain_predictions, explain_predictions_best_worst
 from .permutation_importance import (
     calculate_permutation_importance,
-    calculate_permutation_importance_one_column
+    calculate_permutation_importance_one_column,
 )
