@@ -1,3 +1,4 @@
+import logging
 import warnings
 from operator import add
 
@@ -7,9 +8,8 @@ from sklearn.utils import check_array
 
 from evalml.model_family.model_family import ModelFamily
 from evalml.problem_types import is_binary, is_multiclass, is_regression
-from evalml.utils import get_logger
 
-logger = get_logger(__file__)
+logger = logging.getLogger(__name__)
 
 
 def _create_dictionary(shap_values, feature_names):
