@@ -10,6 +10,7 @@ class BinaryClassificationObjective(ObjectiveBase):
     """Base class for all binary classification objectives."""
 
     problem_types = [ProblemTypes.BINARY, ProblemTypes.TIME_SERIES_BINARY]
+    """[ProblemTypes.BINARY, ProblemTypes.TIME_SERIES_BINARY]"""
 
     @property
     def can_optimize_threshold(cls):
@@ -43,7 +44,10 @@ class BinaryClassificationObjective(ObjectiveBase):
             cost = self.objective_function(y_true, y_predicted, X=X)
             return -cost if self.greater_is_better else cost
 
-        optimal = minimize_scalar(cost, bounds=(0, 1), method="Bounded")
+        optimal = minimize_scalar(
+            cost, bracket=(0, 1), method="Golden", options={"maxiter": 250}
+        )
+
         return optimal.x
 
     def decision_function(self, ypred_proba, threshold=0.5, X=None):
