@@ -1,4 +1,3 @@
-
 from .objective_base import ObjectiveBase
 
 from evalml import objectives
@@ -16,17 +15,26 @@ def get_non_core_objectives():
     Returns:
         List of ObjectiveBase classes
     """
-    return [objectives.CostBenefitMatrix, objectives.FraudCost, objectives.LeadScoring,
-            objectives.Recall, objectives.RecallMacro, objectives.RecallMicro,
-            objectives.RecallWeighted, objectives.MAPE, objectives.MeanSquaredLogError,
-            objectives.RootMeanSquaredLogError]
+    return [
+        objectives.CostBenefitMatrix,
+        objectives.FraudCost,
+        objectives.LeadScoring,
+        objectives.Recall,
+        objectives.RecallMacro,
+        objectives.RecallMicro,
+        objectives.RecallWeighted,
+        objectives.MAPE,
+        objectives.MeanSquaredLogError,
+        objectives.RootMeanSquaredLogError,
+        objectives.SensitivityLowAlert,
+    ]
 
 
 def _all_objectives_dict():
     all_objectives = _get_subclasses(ObjectiveBase)
     objectives_dict = {}
     for objective in all_objectives:
-        if 'evalml.objectives' not in objective.__module__:
+        if "evalml.objectives" not in objective.__module__:
             continue
         objectives_dict[objective.name.lower()] = objective
     return objectives_dict
@@ -50,7 +58,11 @@ def get_core_objective_names():
     """
     all_objectives = _all_objectives_dict()
     non_core = get_non_core_objectives()
-    return [name for name, class_name in all_objectives.items() if class_name not in non_core]
+    return [
+        name
+        for name, class_name in all_objectives.items()
+        if class_name not in non_core
+    ]
 
 
 def get_objective(objective, return_instance=False, **kwargs):
@@ -73,11 +85,15 @@ def get_objective(objective, return_instance=False, **kwargs):
         return objective
     all_objectives_dict = _all_objectives_dict()
     if not isinstance(objective, str):
-        raise TypeError("If parameter objective is not a string, it must be an instance of ObjectiveBase!")
+        raise TypeError(
+            "If parameter objective is not a string, it must be an instance of ObjectiveBase!"
+        )
     if objective.lower() not in all_objectives_dict:
-        raise ObjectiveNotFoundError(f"{objective} is not a valid Objective! "
-                                     "Use evalml.objectives.get_all_objective_names()"
-                                     "to get a list of all valid objective names. ")
+        raise ObjectiveNotFoundError(
+            f"{objective} is not a valid Objective! "
+            "Use evalml.objectives.get_all_objective_names()"
+            "to get a list of all valid objective names. "
+        )
 
     objective_class = all_objectives_dict[objective.lower()]
 
@@ -85,7 +101,9 @@ def get_objective(objective, return_instance=False, **kwargs):
         try:
             return objective_class(**kwargs)
         except TypeError as e:
-            raise ObjectiveCreationError(f"In get_objective, cannot pass in return_instance=True for {objective} because {str(e)}")
+            raise ObjectiveCreationError(
+                f"In get_objective, cannot pass in return_instance=True for {objective} because {str(e)}"
+            )
 
     return objective_class
 
@@ -103,5 +121,10 @@ def get_core_objectives(problem_type):
     """
     problem_type = handle_problem_types(problem_type)
     all_objectives_dict = _all_objectives_dict()
-    objectives = [obj() for obj in all_objectives_dict.values() if obj.is_defined_for_problem_type(problem_type) and obj not in get_non_core_objectives()]
+    objectives = [
+        obj()
+        for obj in all_objectives_dict.values()
+        if obj.is_defined_for_problem_type(problem_type)
+        and obj not in get_non_core_objectives()
+    ]
     return objectives
