@@ -25,8 +25,8 @@ from .components import (
     ExtraTreesRegressor,
     DecisionTreeClassifier,
     DecisionTreeRegressor,
-    StackedEnsembleClassifier,
-    StackedEnsembleRegressor,
+    SklearnStackedEnsembleClassifier,
+    SklearnStackedEnsembleRegressor,
     DelayedFeatureTransformer,
     DFSTransformer,
     KNeighborsClassifier,
