@@ -7,13 +7,11 @@ from evalml.exceptions import MethodPropertyNotFoundError
 from evalml.pipelines.components.component_base_meta import ComponentBaseMeta
 from evalml.utils import (
     classproperty,
-    get_logger,
     infer_feature_types,
     log_subtitle,
     safe_repr,
 )
-
-logger = get_logger(__file__)
+from evalml.utils.logger import get_logger
 
 
 class ComponentBase(ABC, metaclass=ComponentBaseMeta):
@@ -137,6 +135,7 @@ class ComponentBase(ABC, metaclass=ComponentBaseMeta):
         Returns:
             None or dict: prints and returns dictionary
         """
+        logger = get_logger(f"{__name__}.describe")
         if print_name:
             title = self.name
             log_subtitle(logger, title)
