@@ -66,7 +66,7 @@ class ElasticNetClassifier(Estimator):
         solver="saga",
         n_jobs=-1,
         random_seed=0,
-        **kwargs
+        **kwargs,
     ):
         parameters = {
             "penalty": penalty,
