@@ -1,11 +1,16 @@
+import numpy as np
+import pandas as pd
+from pandas.api.types import is_integer_dtype
+from sklearn.preprocessing import LabelEncoder
 from skopt.space import Integer, Real
 
 from evalml.model_family import ModelFamily
 from evalml.pipelines.components.estimators import Estimator
 from evalml.problem_types import ProblemTypes
-from evalml.utils.gen_utils import (
+from evalml.utils import (
     _rename_column_names_to_numeric,
     import_or_raise,
+    infer_feature_types,
 )
 
 
@@ -19,7 +24,7 @@ class XGBoostClassifier(Estimator):
         min_child_weight (float): Minimum sum of instance weight (hessian) needed in a child. Defaults to 1.0
         n_estimators (int): Number of gradient boosted trees. Equivalent to number of boosting rounds. Defaults to 100.
         random_seed (int): Seed for the random number generator. Defaults to 0.
-        n_jobs (int): Number of parallel threads used to run xgboost. Note that creating thread contention will significantly slow down the algorithm. Defaults to -1.
+        n_jobs (int): Number of parallel threads used to run xgboost. Note that creating thread contention will significantly slow down the algorithm. Defaults to 12.
     """
 
     name = "XGBoost Classifier"
@@ -62,7 +67,8 @@ class XGBoostClassifier(Estimator):
         min_child_weight=1,
         n_estimators=100,
         random_seed=0,
-        n_jobs=-1,
+        eval_metric="logloss",
+        n_jobs=12,
         **kwargs,
     ):
         parameters = {
@@ -71,13 +77,19 @@ class XGBoostClassifier(Estimator):
             "min_child_weight": min_child_weight,
             "n_estimators": n_estimators,
             "n_jobs": n_jobs,
+            "eval_metric": eval_metric,
         }
         parameters.update(kwargs)
+        if "use_label_encoder" in parameters:
+            parameters.pop("use_label_encoder")
         xgb_error_msg = (
             "XGBoost is not installed. Please install using `pip install xgboost.`"
         )
         xgb = import_or_raise("xgboost", error_msg=xgb_error_msg)
-        xgb_classifier = xgb.XGBClassifier(random_state=random_seed, **parameters)
+        xgb_classifier = xgb.XGBClassifier(
+            use_label_encoder=False, random_state=random_seed, **parameters
+        )
+        self._label_encoder = None
         super().__init__(
             parameters=parameters, component_obj=xgb_classifier, random_seed=random_seed
         )
@@ -88,11 +100,18 @@ class XGBoostClassifier(Estimator):
             col: "Integer" for col in X.ww.select("boolean", return_schema=True).columns
         }
 
+    def _label_encode(self, y):
+        if not is_integer_dtype(y):
+            self._label_encoder = LabelEncoder()
+            y = pd.Series(self._label_encoder.fit_transform(y), dtype="int64")
+        return y
+
     def fit(self, X, y=None):
         X, y = super()._manage_woodwork(X, y)
         X.ww.set_types(self._convert_bool_to_int(X))
         self.input_feature_names = list(X.columns)
         X = _rename_column_names_to_numeric(X, flatten_tuples=False)
+        y = self._label_encode(y)
         self._component_obj.fit(X, y)
         return self
 
@@ -100,7 +119,13 @@ class XGBoostClassifier(Estimator):
         X, _ = super()._manage_woodwork(X)
         X.ww.set_types(self._convert_bool_to_int(X))
         X = _rename_column_names_to_numeric(X, flatten_tuples=False)
-        return super().predict(X)
+        predictions = super().predict(X)
+        if not self._label_encoder:
+            return predictions
+        predictions = pd.Series(
+            self._label_encoder.inverse_transform(predictions.astype(np.int64))
+        )
+        return infer_feature_types(predictions)
 
     def predict_proba(self, X):
         X, _ = super()._manage_woodwork(X)
