@@ -45,7 +45,7 @@ class RFRegressorSelectFromModel(FeatureSelector):
         threshold=-np.inf,
         n_jobs=-1,
         random_seed=0,
-        **kwargs
+        **kwargs,
     ):
 
         parameters = {
@@ -71,7 +71,7 @@ class RFRegressorSelectFromModel(FeatureSelector):
             estimator=estimator,
             max_features=max_features,
             threshold=threshold,
-            **kwargs
+            **kwargs,
         )
         super().__init__(
             parameters=parameters,
