@@ -1,5 +1,6 @@
 import copy
 import inspect
+import logging
 import os
 import sys
 import traceback
@@ -25,7 +26,6 @@ from evalml.pipelines import ComponentGraph
 from evalml.pipelines.pipeline_meta import PipelineBaseMeta
 from evalml.problem_types import is_binary
 from evalml.utils import (
-    get_logger,
     import_or_raise,
     infer_feature_types,
     jupyter_check,
@@ -33,8 +33,9 @@ from evalml.utils import (
     log_title,
     safe_repr,
 )
+from evalml.utils.logger import get_logger
 
-logger = get_logger(__file__)
+logger = logging.getLogger(__name__)
 
 
 class PipelineBase(ABC, metaclass=PipelineBaseMeta):
@@ -222,6 +223,7 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         Returns:
             dict: Dictionary of all component parameters if return_dict is True, else None
         """
+        logger = get_logger(f"{__name__}.describe")
         log_title(logger, self.name)
         logger.info("Problem Type: {}".format(self.problem_type))
         logger.info("Model Family: {}".format(str(self.model_family)))
@@ -247,11 +249,14 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
             pipeline_dict.update({"components": component_dict})
             return pipeline_dict
 
-    def compute_estimator_features(self, X, y=None):
+    def compute_estimator_features(self, X, y=None, X_train=None, y_train=None):
         """Transforms the data by applying all pre-processing components.
 
         Arguments:
             X (pd.DataFrame): Input data to the pipeline to transform.
+            y (pd.Series or None): Targets corresponding to X. optional.
+            X_train (pd.DataFrame or np.ndarray or None): Training data. Only used for time series.
+            y_train (pd.Series or None): Training labels.  Only used for time series.
 
         Returns:
             pd.DataFrame: New transformed features.
@@ -288,12 +293,14 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         """
         return self.component_graph.transform(X, y)
 
-    def predict(self, X, objective=None):
+    def predict(self, X, objective=None, X_train=None, y_train=None):
         """Make predictions using selected features.
 
         Arguments:
             X (pd.DataFrame, or np.ndarray): Data of shape [n_samples, n_features].
             objective (Object or string): The objective to use to make predictions.
+            X_train (pd.DataFrame or np.ndarray or None): Training data. Ignored. Only used for time series.
+            y_train (pd.Series or None): Training labels. Ignored. Only used for time series.
 
         Returns:
             pd.Series: Predicted values.
@@ -304,13 +311,15 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         return infer_feature_types(predictions)
 
     @abstractmethod
-    def score(self, X, y, objectives):
+    def score(self, X, y, objectives, X_train=None, y_train=None):
         """Evaluate model performance on current and additional objectives.
 
         Arguments:
             X (pd.DataFrame or np.ndarray): Data of shape [n_samples, n_features].
             y (pd.Series, np.ndarray): True labels of length [n_samples].
             objectives (list): Non-empty list of objectives to score on.
+            X_train (pd.DataFrame or np.ndarray or None): Training data. Ignored. Only used for time series.
+            y_train (pd.Series or None): Training labels. Ignored. Only used for time series.
 
         Returns:
             dict: Ordered dictionary of objective scores.
