@@ -1,10 +1,5 @@
 from evalml.pipelines.time_series_pipeline_base import TimeSeriesPipelineBase
 from evalml.problem_types import ProblemTypes
-from evalml.utils import (
-    drop_rows_with_nans,
-    infer_feature_types,
-    pad_with_nans,
-)
 
 
 class TimeSeriesRegressionPipeline(TimeSeriesPipelineBase):
@@ -26,49 +21,23 @@ class TimeSeriesRegressionPipeline(TimeSeriesPipelineBase):
     problem_type = ProblemTypes.TIME_SERIES_REGRESSION
     """ProblemTypes.TIME_SERIES_REGRESSION"""
 
-    def predict(self, X, y=None, objective=None):
-        """Make predictions using selected features.
-
-        Arguments:
-            X (pd.DataFrame, or np.ndarray): Data of shape [n_samples, n_features].
-            y (pd.Series, np.ndarray, None): The target training targets of length [n_samples].
-            objective (Object or string): The objective to use to make predictions.
-
-        Returns:
-            pd.Series: Predicted values.
-        """
-        if self.estimator is None:
-            raise ValueError(
-                "Cannot call predict() on a component graph because the final component is not an Estimator."
-            )
-        X, y = self._convert_to_woodwork(X, y)
-        features = self.compute_estimator_features(X, y)
-        features_no_nan, y = drop_rows_with_nans(features, y)
-        predictions = self._estimator_predict(features_no_nan, y)
-        predictions.index = y.index
-        predictions = self.inverse_transform(predictions)
-        predictions = predictions.rename(self.input_target_name)
-        padded = pad_with_nans(
-            predictions, max(0, features.shape[0] - predictions.shape[0])
-        )
-        return infer_feature_types(padded)
-
-    def score(self, X, y, objectives):
+    def score(self, X, y, objectives, X_train=None, y_train=None):
         """Evaluate model performance on current and additional objectives.
 
         Arguments:
             X (pd.DataFrame or np.ndarray): Data of shape [n_samples, n_features].
             y (pd.Series): True labels of length [n_samples].
             objectives (list): Non-empty list of objectives to score on.
+            X_train (pd.DataFrame, np.ndarray): Data the pipeline was trained on of shape [n_samples_train, n_feautures].
+            y_train (pd.Series, np.ndarray): Targets used to train the pipeline of shape [n_samples_train].
 
         Returns:
             dict: Ordered dictionary of objective scores.
         """
         X, y = self._convert_to_woodwork(X, y)
+        X_train, y_train = self._convert_to_woodwork(X_train, y_train)
         objectives = self.create_objectives(objectives)
-        y_predicted = self.predict(X, y)
-        y_shifted = y.shift(-self.gap)
-        y_shifted, y_predicted = drop_rows_with_nans(y_shifted, y_predicted)
+        y_predicted = self.predict_in_sample(X, y, X_train, y_train)
         return self._score_all_objectives(
-            X, y_shifted, y_predicted, y_pred_proba=None, objectives=objectives
+            X, y, y_predicted, y_pred_proba=None, objectives=objectives
         )
