@@ -122,29 +122,3 @@ def target_distribution(targets):
     """
     distribution = targets.value_counts() / len(targets)
     return distribution.mul(100).apply("{:.2f}%".format).rename_axis("Targets")
-
-
-def drop_nan_target_rows(X, y):
-    """Drops rows in X and y when row in the target y has a value of NaN.
-
-    Arguments:
-        X (pd.DataFrame, np.ndarray): Data to transform
-        y (pd.Series, np.ndarray): Target data
-
-    Returns:
-        pd.DataFrame, pd.DataFrame: Transformed X (and y, if passed in) with rows that had a NaN value removed.
-    """
-    X_t = X
-    y_t = y
-
-    if not isinstance(X_t, pd.DataFrame):
-        X_t = pd.DataFrame(X_t)
-
-    if not isinstance(y_t, pd.Series):
-        y_t = pd.Series(y_t)
-
-    # drop rows where corresponding y is NaN
-    y_null_indices = y_t.index[y_t.isna()]
-    X_t = X_t.drop(index=y_null_indices)
-    y_t.dropna(inplace=True)
-    return X_t, y_t
