@@ -17,6 +17,17 @@ from evalml.pipelines.components import OneHotEncoder
 from evalml.utils import get_random_seed, infer_feature_types
 
 
+def set_first_three_columns_to_categorical(X):
+    X.ww.init(
+        logical_types={
+            "col_1": "categorical",
+            "col_2": "categorical",
+            "col_3": "categorical",
+        }
+    )
+    return X
+
+
 def test_init():
     parameters = {
         "top_n": 10,
@@ -78,7 +89,7 @@ def test_null_values_in_dataframe():
             "col_3": ["a", "a", "a", "a", "a"],
         }
     )
-
+    X.ww.init(logical_types={"col_1": "categorical", "col_2": "categorical"})
     # Test NaN will be counted as a category if within the top_n
     encoder = OneHotEncoder(handle_missing="as_category")
     encoder.fit(X)
@@ -110,7 +121,7 @@ def test_null_values_in_dataframe():
             "col_4": [2, 0, 1, np.nan, 0],
         }
     )
-
+    X.ww.init(logical_types={"col_1": "categorical", "col_2": "categorical"})
     encoder = OneHotEncoder(top_n=2, handle_missing="as_category")
     encoder.fit(X)
     X_t = encoder.transform(X)
@@ -166,6 +177,7 @@ def test_drop_first():
             "col_3": ["a", "a", "a", "a", "a"],
         }
     )
+    X = set_first_three_columns_to_categorical(X)
     encoder = OneHotEncoder(top_n=None, drop="first", handle_unknown="error")
     encoder.fit(X)
     X_t = encoder.transform(X)
@@ -182,6 +194,7 @@ def test_drop_binary():
             "col_3": ["a", "a", "a", "a", "a"],
         }
     )
+    X = set_first_three_columns_to_categorical(X)
     encoder = OneHotEncoder(top_n=None, drop="if_binary", handle_unknown="error")
     encoder.fit(X)
     X_t = encoder.transform(X)
@@ -198,6 +211,7 @@ def test_drop_parameter_is_array():
             "col_3": ["a", "a", "a", "a", "a"],
         }
     )
+    X = set_first_three_columns_to_categorical(X)
     encoder = OneHotEncoder(top_n=None, drop=["b", "c", "a"], handle_unknown="error")
     encoder.fit(X)
     X_t = encoder.transform(X)
@@ -216,6 +230,7 @@ def test_drop_binary_and_top_n_2():
             "col_3": ["a", "a", "a", "a", "a"],
         }
     )
+    X = set_first_three_columns_to_categorical(X)
     encoder = OneHotEncoder(top_n=2, drop="if_binary")
     encoder.fit(X)
     X_t = encoder.transform(X)
@@ -233,7 +248,7 @@ def test_handle_unknown():
             "col_4": [2, 0, 1, 3, 0, 1, 2],
         }
     )
-
+    X = set_first_three_columns_to_categorical(X)
     encoder = OneHotEncoder(handle_unknown="error")
     encoder.fit(X)
     assert isinstance(encoder.transform(X), pd.DataFrame)
@@ -261,6 +276,7 @@ def test_no_top_n():
             "col_4": [2, 0, 1, 3, 0, 1, 2, 0, 2, 1, 2],
         }
     )
+    X.ww.init(logical_types={"col_1": "categorical", "col_2": "categorical"})
     expected_col_names = set(["col_3_b", "col_4"])
     for val in X["col_1"]:
         expected_col_names.add("col_1_" + val)
@@ -299,6 +315,7 @@ def test_categories():
             "col_4": [2, 0, 1, 3, 0, 1, 2],
         }
     )
+    X = set_first_three_columns_to_categorical(X)
 
     categories = [["a", "b", "c", "d"], ["a", "b", "c"], ["a", "b"]]
 
@@ -342,7 +359,7 @@ def test_less_than_top_n_unique_values():
             "col_4": [2, 0, 1, 0, 0],
         }
     )
-
+    X.ww.init(logical_types={"col_1": "categorical", "col_2": "categorical"})
     encoder = OneHotEncoder(top_n=5)
     encoder.fit(X)
     X_t = encoder.transform(X)
@@ -373,6 +390,7 @@ def test_more_top_n_unique_values():
             "col_4": [2, 0, 1, 3, 0, 1, 2],
         }
     )
+    X = set_first_three_columns_to_categorical(X)
 
     random_seed = 2
 
@@ -415,7 +433,7 @@ def test_more_top_n_unique_values_large():
             "col_4": [2, 0, 1, 3, 0, 1, 2, 4, 1],
         }
     )
-
+    X = set_first_three_columns_to_categorical(X)
     random_seed = 2
 
     encoder = OneHotEncoder(top_n=3, random_seed=random_seed)
@@ -451,6 +469,7 @@ def test_categorical_dtype():
         }
     )
     X["col_4"] = X["col_4"].astype("category")
+    X.ww.init(logical_types={"col_1": "categorical", "col_2": "categorical"})
 
     encoder = OneHotEncoder(top_n=5)
     encoder.fit(X)
@@ -521,21 +540,24 @@ def test_large_number_of_categories():
 @pytest.mark.parametrize("data_type", ["list", "np", "pd_no_index", "pd_index", "ww"])
 def test_data_types(data_type):
     if data_type == "list":
-        X = [["a"], ["b"], ["c"]]
+        X = [["a"], ["b"], ["c"]] * 5
     elif data_type == "np":
-        X = np.array([["a"], ["b"], ["c"]])
+        X = np.array([["a"], ["b"], ["c"]] * 5)
     elif data_type == "pd_no_index":
-        X = pd.DataFrame(["a", "b", "c"])
+        X = pd.DataFrame(["a", "b", "c"] * 5)
     elif data_type == "pd_index":
-        X = pd.DataFrame(["a", "b", "c"], columns=["0"])
+        X = pd.DataFrame(["a", "b", "c"] * 5, columns=["0"])
     elif data_type == "ww":
-        X = pd.DataFrame(["a", "b", "c"])
+        X = pd.DataFrame(["a", "b", "c"] * 5)
         X.ww.init()
     encoder = OneHotEncoder()
     encoder.fit(X)
     X_t = encoder.transform(X)
     assert list(X_t.columns) == ["0_a", "0_b", "0_c"]
-    np.testing.assert_array_equal(X_t.to_numpy(), np.identity(3))
+    mask = np.identity(3)
+    for _ in range(4):
+        mask = np.vstack((mask, np.identity(3)))
+    np.testing.assert_array_equal(X_t.to_numpy(), mask)
 
 
 @pytest.mark.parametrize(
@@ -563,6 +585,7 @@ def test_ohe_categories():
     X = pd.DataFrame(
         {"col_1": ["a"] * 10, "col_2": ["a"] * 3 + ["b"] * 3 + ["c"] * 2 + ["d"] * 2}
     )
+    X.ww.init(logical_types={"col_2": "categorical"})
     ohe = OneHotEncoder(top_n=2)
     with pytest.raises(
         ComponentNotYetFittedError,
@@ -584,6 +607,7 @@ def test_ohe_get_feature_names():
     X = pd.DataFrame(
         {"col_1": ["a"] * 10, "col_2": ["a"] * 3 + ["b"] * 3 + ["c"] * 2 + ["d"] * 2}
     )
+    X.ww.init(logical_types={"col_2": "categorical"})
     ohe = OneHotEncoder(top_n=2)
     with pytest.raises(
         ComponentNotYetFittedError,
@@ -671,6 +695,7 @@ def test_ohe_top_n_categories_always_the_same():
 
 def test_ohe_column_names_unique():
     df = pd.DataFrame({"A": ["x_y"], "A_x": ["y"]})
+    df.ww.init(logical_types={"A": "categorical", "A_x": "categorical"})
     df_transformed = OneHotEncoder().fit_transform(df)
     assert set(df_transformed.columns) == {"A_x_y", "A_x_y_1"}
 
@@ -685,6 +710,9 @@ def test_ohe_column_names_unique():
             "A_x_y": ["1", "y", "y"],
         }
     )
+    df.ww.init(
+        logical_types={"A": "categorical", "A_x": "categorical", "A_x_y": "categorical"}
+    )
     df_transformed = OneHotEncoder().fit_transform(df)
     # category y in A_x gets mapped to A_x_y_1 because A_x_y already exists
     # category 1 in A_x_y gets mapped to A_x_y_1_1 because A_x_y_1 already exists
@@ -693,6 +721,9 @@ def test_ohe_column_names_unique():
     df = pd.DataFrame(
         {"A": ["x_y", "z", "a"], "A_x": ["y_1", "y", "b"], "A_x_y": ["1", "y", "c"]}
     )
+    df.ww.init(
+        logical_types={"A": "categorical", "A_x": "categorical", "A_x_y": "categorical"}
+    )
     df_transformed = OneHotEncoder().fit_transform(df)
     # category y in A_x gets mapped to A_x_y_1 because A_x_y already exists
     # category y_1 in A_x gets mapped to A_x_y_1_1 because A_x_y_1 already exists
