@@ -1,4 +1,5 @@
 import string
+import warnings
 
 import numpy as np
 import pandas as pd
@@ -12,6 +13,17 @@ from evalml.utils import SEED_BOUNDS, get_random_state
 xgb = importorskip("xgboost", reason="Skipping test because xgboost not installed")
 
 
+@pytest.mark.parametrize("metric", ["error", "logloss"])
+def test_xgboost_classifier_default_evaluation_metric(metric):
+    xgb = XGBoostClassifier(eval_metric=metric)
+    assert xgb.parameters["eval_metric"] == metric
+    assert xgb._component_obj.get_params()["eval_metric"] == metric
+
+    xgb = XGBoostClassifier()
+    assert xgb.parameters["eval_metric"] == "logloss"
+    assert xgb._component_obj.get_params()["eval_metric"] == "logloss"
+
+
 def test_xgboost_classifier_random_seed_bounds_seed(X_y_binary):
     """ensure xgboost's RNG doesn't fail for the min/max bounds we support on user-inputted random seeds"""
     X, y = X_y_binary
@@ -84,3 +96,29 @@ def test_xgboost_predict_all_boolean_columns():
     preds = xgb.predict(X)
     assert isinstance(preds, pd.Series)
     assert not preds.isna().any()
+
+
+@pytest.mark.parametrize(
+    "y,label_encoder",
+    [
+        ([True, False, False], True),
+        ([1.0, 1.1, 1.1], True),
+        (["One", "Two", "Two"], True),
+        ([0, 1, 1], False),
+    ],
+)
+def test_xgboost_catch_warnings_label_encoder(y, label_encoder):
+    X = pd.DataFrame({"a": [True, False, True], "b": [True, False, True]})
+    y = pd.Series(y)
+    xgb = XGBoostClassifier()
+    with warnings.catch_warnings(record=True) as w:
+        warnings.simplefilter("always")
+        xgb.fit(X, y)
+    assert len(w) == 0
+    preds = xgb.predict(X)
+    # make sure the predicted outputs are the same labels as the passed-in labels
+    assert preds[0] in y.values
+    if label_encoder:
+        assert xgb._label_encoder is not None
+        return
+    assert xgb._label_encoder is None
