@@ -221,7 +221,7 @@ def X_y_binary():
     return X, y
 
 
-@pytest.fixture
+@pytest.fixture(scope="session")
 def X_y_binary_cls():
     X, y = datasets.make_classification(
         n_samples=100, n_features=20, n_informative=2, n_redundant=2, random_state=0
@@ -741,6 +741,7 @@ def decision_tree_classification_pipeline_class(X_y_categorical_classification):
         }
     )
     X, y = X_y_categorical_classification
+    X.ww.init(logical_types={"Ticket": "categorical", "Cabin": "categorical"})
     pipeline.fit(X, y)
     return pipeline
 
@@ -989,7 +990,14 @@ def fraud_local():
 @pytest.fixture
 def fraud_100():
     X, y = load_fraud_local(n_rows=100)
-    X.ww.set_types(logical_types={"provider": "Categorical", "region": "Categorical"})
+    X.ww.set_types(
+        logical_types={
+            "provider": "Categorical",
+            "region": "Categorical",
+            "currency": "categorical",
+            "expiration_date": "categorical",
+        }
+    )
     return X, y
 
 
@@ -1127,6 +1135,7 @@ class _AutoMLTestEnv:
         self._mock_fit = None
         self._mock_tell = None
         self._mock_score = None
+        self._mock_get_names = None
         self._mock_encode_targets = None
         self._mock_predict_proba = None
         self._mock_optimize_threshold = None
@@ -1158,6 +1167,7 @@ class _AutoMLTestEnv:
         self._mock_fit = None
         self._mock_tell = None
         self._mock_score = None
+        self._mock_get_names = None
         self._mock_encode_targets = None
         self._mock_predict_proba = None
         self._mock_optimize_threshold = None
@@ -1223,6 +1233,9 @@ class _AutoMLTestEnv:
         mock_score = self._patch_method(
             "score", side_effect=mock_score_side_effect, return_value=score_return_value
         )
+        mock_get_names = patch(
+            "evalml.pipelines.components.FeatureSelector.get_names", return_value=[]
+        )
 
         # For simplicity, we will always mock predict_proba and _encode_targets even if the problem is not a
         # classification problem. For regression problems, we'll mock BinaryClassificationPipeline but it doesn't
@@ -1262,12 +1275,13 @@ class _AutoMLTestEnv:
             "evalml.automl.AutoMLSearch._sleep_time", new_callable=sleep_time
         )
 
-        with mock_sleep, mock_fit as fit, mock_score as score, mock_encode_targets as encode, mock_predict_proba as proba, mock_tell as tell, mock_optimize as optimize:
+        with mock_sleep, mock_fit as fit, mock_score as score, mock_get_names as get_names, mock_encode_targets as encode, mock_predict_proba as proba, mock_tell as tell, mock_optimize as optimize:
             # Can think of `yield` as blocking this method until the computation finishes running
             yield
             self._mock_fit = fit
             self._mock_tell = tell
             self._mock_score = score
+            self._mock_get_names = get_names
             self._mock_encode_targets = encode
             self._mock_predict_proba = proba
             self._mock_optimize_threshold = optimize
