@@ -11,8 +11,6 @@ from psutil._common import bytes2human
 import evalml
 from evalml.utils import get_logger
 
-logger = get_logger(__file__)
-
 
 def print_info():
     """Prints information about the system, evalml, and dependencies of evalml.
@@ -20,6 +18,7 @@ def print_info():
     Returns:
         None
     """
+    logger = get_logger(__name__)
     logger.info("EvalML version: %s" % evalml.__version__)
     logger.info("EvalML installation directory: %s" % get_evalml_root())
     print_sys_info()
@@ -32,6 +31,7 @@ def print_sys_info():
     Returns:
         None
     """
+    logger = get_logger(__name__)
     logger.info("\nSYSTEM INFO")
     logger.info("-----------")
     sys_info = get_sys_info()
@@ -45,6 +45,7 @@ def print_deps():
     Returns:
         None
     """
+    logger = get_logger(__name__)
     logger.info("\nINSTALLED VERSIONS")
     logger.info("------------------")
     installed_packages = get_installed_packages()
